Contributor License Agreement (CLA)

Thank you for your interest in contributing to Artifex.

By signing this CLA (electronically via GitHub or other integrated tools), you agree to the following terms for your contributions (past, present, and future):

1. <ins>**Originality**</ins>:
   You confirm that your contributions are your own work, or that you have the right to submit them.

2. <ins>**License**</ins>:
   You grant Riccardo Lucato an irrevocable, worldwide, non-exclusive, royalty-free license to use, reproduce, modify, distribute, and sublicense your contributions under the MIT License (or any other license used by the project).

3. <ins>**Employment and third-party rights**</ins>:
   You confirm that your contributions are not subject to any third-party rights, including those of your employer or clients. If such rights  could exist, you confirm that you have obtained a valid and sufficient waiver or permission to contribute the work under this CLA and the project’s open source license. You agree that neither your employer nor any third party will have any claim or rights over your contributions to this project.

4. <ins>**Disclaimer**</ins>:
   Contributions are provided "as-is" without warranties or conditions of any kind.

By electronically signing this CLA, you accept these terms and certify that you have the legal authority to do so.